@@ -1,6 +1,6 @@
-from .logger import MixedLogging
+from .logger_v2 import MixedLogging
 
-__version__ = "0.0.6"
+__version__ = "0.0.7"
 
 __all__ = (
     "__version__",
